@@ -4,16 +4,17 @@
 	class browser_with_os_controller extends controller {
 		public function execute() {
 			$filter = new filter($this->db, $this->output);
-			$filter->to_output("requests");
+			$filter->to_output("requests", true);
 
-			$begin = date("Y-m-d", strtotime("-".MONITOR_DAYS." days"));
-			$end = date("Y-m-d", strtotime("tomorrow"));
-
-			if (($info = $this->model->get_information($begin, $end, $filter->hostname, $filter->webserver)) === false) {
+			if (($info = $this->model->get_information($filter->hostname, $filter->webserver)) === false) {
 				$this->output->add_tag("result", "Database error.");
 				return;
 			}
 
+			if ($filter->browser_version == false) {
+				$info = $this->model->remove_browser_version($info);
+			}
+
 			$max = 0;
 			foreach ($info as $item) {
 				if ($item["count"] > $max) {
@@ -26,7 +27,7 @@
 			$this->output->open_tag("info", array("label" => "Web browser with Operating System"));
 			foreach ($info as $item) {
 				$count = $max == 0 ? 0 : (int)(PIXELS * $item["count"] / $max);
-				if ($count < BROWSER_OS_MIN_COUNT) {
+				if ($count < $this->settings->browser_os_min_count) {
 					continue;
 				}
 				$this->output->add_tag("item", $item["info"], array("count" => $count));
