@@ -4,16 +4,17 @@
 	class web_browser_controller extends controller {
 		public function execute() {
 			$filter = new filter($this->db, $this->output);
-			$filter->to_output("requests");
+			$filter->to_output("requests", true);
 
-			$begin = date("Y-m-d", strtotime("-".MONITOR_DAYS." days"));
-			$end = date("Y-m-d", strtotime("tomorrow"));
-
-			if (($info = $this->model->get_information($begin, $end, $filter->hostname, $filter->webserver)) === false) {
+			if (($info = $this->model->get_information($filter->hostname, $filter->webserver)) === false) {
 				$this->output->add_tag("result", "Database error.");
 				return;
 			}
 
+			if ($filter->browser_version == false) {
+				$info = $this->model->remove_browser_version($info);
+			}
+
 			$max = 0;
 			foreach ($info as $browser) {
 				if ($browser["count"] > $max) {
