@@ -256,7 +256,8 @@
 				return $resource;
 			}
 
-			$statement = strtolower(array_shift(explode(" ", ltrim($args[0]), 2)));
+			$parts = explode(" ", ltrim($args[0]), 2);
+			$statement = strtolower(array_shift($parts));
 
 			if (in_array($statement, array("select", "show", "describe", "explain"))) {
 				$result = array();
