@@ -3,7 +3,7 @@
 	 *
 	 * Copyright (C) by Hugo Leisink <hugo@leisink.net>
 	 * This file is part of the Banshee PHP framework
-	 * http://www.hiawatha-webserver.org/banshee
+	 * http://www.banshee-php.org/
 	 */
 
 	class email {
@@ -13,9 +13,7 @@
 		protected $from = null;
 		protected $reply_to = null;
 		protected $subject = null;
-		protected $message = null;
-		protected $content_type = "text/plain";
-		protected $boundary = null;
+		protected $messages = array();
 		protected $attachments = array();
 		protected $sender_address = null;
 
@@ -26,12 +24,13 @@
 		 * ERROR:  -
 		 */
 		public function __construct($subject, $from_address = null, $from_name = null) {
-			$this->subject = array_shift(explode("\n", $subject));
-			if ($this->valid_email($from_address)) {
+			$parts = explode("\n", $subject);
+			$this->subject = trim(array_shift($parts));
+
+			if ($this->valid_address($from_address)) {
 				$this->from = $this->make_address($from_address, $from_name);
 				$this->sender_address = $from_address;
 			}
-			$this->boundary = substr(md5(time()), 0, 10);
 		}
 
 		/* Validate an e-mail address
@@ -40,8 +39,8 @@
 		* OUTPUT: boolean e-mail address oke
 		* ERROR:  -
 		*/
-		protected function valid_email($email) {
-			return eregi("^[0-9a-z]([-_.~]?[0-9a-z])*@[0-9a-z]([-.]?[0-9a-z])*\\.[a-z]{2,4}$", $email) != false;
+		public static function valid_address($email) {
+			return preg_match("/^[0-9A-Za-z]([-_.~]?[0-9A-Za-z])*@[0-9A-Za-z]([-.]?[0-9A-Za-z])*\\.[A-Za-z]{2,4}$/", $email) === 1;
 		}
 
 		/* Combine name and e-mail address
@@ -51,9 +50,16 @@
 		 * ERROR:  -
 		 */
 		protected function make_address($address, $name) {
-			$name = array_shift(explode("\n", $name));
+			$address = strtolower($address);
 
-			return $name === null ? $address : $name." <".$address.">";
+			if ($name === null) {
+				return $address;
+			}
+
+			$parts = explode("\n", $name);
+			$name = trim(array_shift($parts));
+
+			return $name." <".$address.">";
 		}
 
 		/* Set reply-to
@@ -63,7 +69,7 @@
 		 * ERROR:  -
 		 */
 		public function reply_to($address, $name = null) {
-			if ($this->valid_email($address) == false) {
+			if ($this->valid_address($address) == false) {
 				return false;
 			}
 
@@ -80,7 +86,7 @@
 		 * ERROR:  -
 		 */
 		public function to($address, $name = null) {
-			if ($this->valid_email($address) == false) {
+			if ($this->valid_address($address) == false) {
 				return false;
 			}
 
@@ -110,7 +116,7 @@
 		 * ERROR:  -
 		 */
 		public function cc($address, $name = null) {
-			if ($this->valid_email($address) == false) {
+			if ($this->valid_address($address) == false) {
 				return false;
 			}
 
@@ -126,7 +132,7 @@
 		 * ERROR:  -
 		 */
 		public function bcc($address, $name = null) {
-			if ($this->valid_email($address) == false) {
+			if ($this->valid_address($address) == false) {
 				return false;
 			}
 
@@ -137,27 +143,35 @@
 
 		/* Set e-mail message
 		 *
-		 * INPUT:  string message
+		 * INPUT:  string message[, string content type]
 		 * OUTPUT: -
 		 * ERROR:  -
 		 */
-		public function message($message) {	
+		public function message($message, $content_type = null) {
+			$message = str_replace("\r\n", "\n", $message);
+
 			/* Determine message mimetype
 			 */
-			if ((substr($message, 0, 5) == "<body") && (substr(rtrim($message), -7) == "</body>")) {
-				$this->content_type = "text/html";
+			if ($content_type === null) {
+				if ((substr($message, 0, 6) == "<html>") && (substr(rtrim($message), -7) == "</html>")) {
+					$content_type = "text/html";
+				} else {
+					$content_type = "text/plain";
+				}
 			}
 
-			$this->message = $message;
+			array_push($this->messages, array(
+				"message"      => $message,
+				"content_type" => $content_type));
 		}
 
 		/* Add e-mail attachment
 		 *
 		 * INPUT:  string filename[, string content][, string content type]
-		 * OUTPUT: boolean attaching successful
-		 * ERROR:  -
+		 * OUTPUT: true
+		 * ERROR:  false
 		 */
-		public function attachment($filename, $content = null, $content_type = null) {
+		public function add_attachment($filename, $content = null, $content_type = null) {
 			if ($content == null) {
 				/* Load content from file
 				 */
@@ -182,8 +196,8 @@
 			/* Add attachment
 			 */
 			array_push($this->attachments, array(
-				"filename" => $filename,
-				"content" => $content,
+				"filename"     => $filename,
+				"content"      => $content,
 				"content_type" => $content_type));
 
 			return true;
@@ -192,57 +206,103 @@
 		/* Send e-mail
 		 *
 		 * INPUT:  [string e-mail address recipient][, string name recipient]
-		 * OUTPUT: boolean sending successful
-		 * ERROR:  -
+		 * OUTPUT: true
+		 * ERROR:  false
 		 */
 		public function send($to_address = null, $to_name = null) {
 			if ($to_address !== null) {
-				if ($this->valid_email($to_address) == false) {
+				if ($this->to($to_address, $to_name) == false) {
 					return false;
 				}
-
-				$this->to($to_address, $to_name);
 			}
 
-			if ((count($this->to) == 0) || ($this->message === null)) {
+			if (count($this->to) == 0) {
 				return false;
 			}
 
-			if (count($this->attachments) > 0) {
-				/* E-mail with attachments
+			if (count($this->messages) == 0) {
+				$this->message("");
+			}
+
+			$message_count = count($this->messages);
+			$attachment_count = count($this->attachments);
+			$email_boundary = substr(md5(time()), 0, 20);
+
+			/* E-mail content
+			 */
+			if ($attachment_count == 0) {
+				/* No attachments
 				 */
-				$headers = array("Content-Type: multipart/mixed; boundary=".$this->boundary);
-				$message = "";
+				if ($message_count == 1) {
+					/* One message
+					 */
+					$headers = array("Content-Type: ".$this->messages[0]["content_type"]);
+					$message = $this->messages[0]["message"];
+				} else {
+					/* Multiple messages
+					 */
+					$headers = array("Content-Type: multipart/alternative; boundary=".$email_boundary);
+					$message = "This is a multi-part message in MIME format.\n";
+					foreach ($this->messages as $mesg) {
+						$message .=
+							"--".$email_boundary."\n".
+							"Content-Type: ".$mesg["content_type"]."\n".
+							"Content-Transfer-Encoding: 7bit\n\n".
+							$mesg["message"]."\n\n";
+					}
+				}
+			} else {
+				/* With attachments
+				 */
+				$headers = array("Content-Type: multipart/mixed; boundary=".$email_boundary);
+				$message = "This is a multi-part message in MIME format.\n";
+
+				if ($message_count == 1) {
+					/* One message
+					 */
+					$message .=
+						"--".$email_boundary."\n".
+						"Content-Type: ".$this->messages[0]["content_type"]."\n".
+						"Content-Transfer-Encoding: 7bit\n\n".
+						$this->messages[0]["message"]."\n\n";
+				} else {
+					/* Multiple messages
+					 */
+					$message_boundary = substr(md5($email_boundary), 0, 20);
+					$message .= "--".$email_boundary."\n".
+						"Content-Type: multipart/alternative; boundary=".$message_boundary."\n\n";
+					foreach ($this->messages as $mesg) {
+						$message .=
+							"--".$message_boundary."\n".
+							"Content-Type: ".$mesg["content_type"]."\n".
+							"Content-Transfer-Encoding: 7bit\n\n".
+							$mesg["message"]."\n\n";
+					}
+					$message .= "--".$message_boundary."--\n\n";
+				}
 
 				/* Add attachments
 				 */
 				foreach ($this->attachments as $attachment) {
 					$content = base64_encode($attachment["content"]);
-					$content = wordwrap($content, 75, "\n", true);
+					$content = wordwrap($content, 70, "\n", true);
 					$message .=
-						"--".$this->boundary."\n".
+						"--".$email_boundary."\n".
 						"Content-Disposition: attachment;\n".
-						"\tfilename=".$attachment["filename"]."\n".
-						"Content-Type: ".$attachment["content_type"]."\n".
+						"\tfilename=\"".$attachment["filename"]."\"\n".
+						"Content-Type: ".$attachment["content_type"].";\n".
+						"\tname=\"".$attachment["filename"]."\"\n".
 						"Content-Transfer-Encoding: base64\n\n".
 						$content."\n\n";
 				}
-
-				/* Add message
-				 */
-				$message .= 
-					"--".$this->boundary."\n".
-					"Content-Type: ".$this->content_type."\n\n".
-					$this->message."\n".
-					"--".$this->boundary."--\n";
-			} else {
-				/* E-mail without attachments
-				 */
-				$headers = array("Content-Type: ".$this->content_type);
-				$message = $this->message;
 			}
 
-			array_push($headers, "User-Agent: Banshee PHP framework e-mail library");
+			if (($message_count > 1) || ($attachment_count > 0)) {
+				$message .= "--".$email_boundary."--\n";
+			}
+
+			array_push($headers, "MIME-Version: 1.0");
+			array_push($headers, "User-Agent: Banshee PHP framework e-mail library (http://www.banshee-php.org/)");
 
 			/* Sender
 			 */
@@ -252,6 +312,7 @@
 			if ($this->reply_to != null) {
 				array_push($headers, "Reply-To: ".$this->reply_to);
 			}
+			$sender = ($this->sender_address !== null) ? "-f".$this->sender_address : null;
 
 			/* Carbon Copies
 			 */
@@ -274,7 +335,7 @@
 
 			/* Send the e-mail
 			 */
-			if (mail(implode(", ", $this->to), $this->subject, $message, implode("\n", $headers), "-f".$this->sender_address) == false) {
+			if (mail(implode(", ", $this->to), $this->subject, $message, implode("\n", $headers), $sender) == false) {
 				return false;
 			}
 
