@@ -16,6 +16,7 @@
 		private $connect_port = null;
 		protected $default_port = 80;
 		protected $protocol = "";
+		protected $timeout = 5;
 
 		/* Constructor
 		 *
@@ -147,7 +148,7 @@
 		 * ERROR:  false
 		 */
 		protected function perform_request($method, $url, $body = "") {
-			if (($sock = fsockopen($this->protocol.$this->connect_host, $this->connect_port)) == false) {
+			if (($sock = @fsockopen($this->protocol.$this->connect_host, $this->connect_port, $errno, $errstr, $this->timeout)) == false) {
 				return false;
 			}
 
