@@ -11,6 +11,7 @@
 	final class output extends XML {
 		private $settings = null;
 		private $page = null;
+		private $mode = null;
 		private $language = null;
 		private $description = null;
 		private $keywords = null;
@@ -23,7 +24,7 @@
 		private $css_links = array();
 		private $inline_css = null;
 		private $content_type = "text/html; charset=utf-8";
-		private $layout = "layout_site";
+		private $layout = LAYOUT_SITE;
 		private $disabled = false;
 
 		/* Constructor
@@ -33,24 +34,21 @@
 		 * ERROR:  -
 		 */
 		public function __construct($db, $settings, $page) {
+			parent::__construct($db);
+			$this->settings = $settings;
+			$this->page = $page;
+
+			if (isset($_GET["output"])) {
+				$this->mode = $_GET["output"];
+			} else if ($this->page->ajax_request) {
+				$this->mode = "xml";
+			}
+
 			$this->language = $settings->default_language;
 			$this->description = $settings->head_description;
 			$this->keywords = $settings->head_keywords;
 
-			$this->settings = $settings;
-			$this->page = $page;
-			parent::__construct($db);
-
-			/* Page layout
-			 */
-			$inherit_layout = array(LOGOUT_MODULE, "password");
-			if (substr($this->page->url, 0, 6) == "/admin") {
-				$this->layout = "layout_cms";
-			} else if (in_array($this->page->module, $inherit_layout)) {
-				if ($_SESSION["previous_layout"] == "layout_cms") {
-					$this->layout = "layout_cms";
-				}
-			}
+			$this->set_layout();
 		}
 
 		/* Constructor
@@ -71,6 +69,7 @@
 		 */
 		public function __get($key) {
 			switch ($key) {
+				case "mode": return $this->mode;
 				case "language": return $this->language;
 				case "description": return $this->description;
 				case "keywords": return $this->keywords;
@@ -92,6 +91,7 @@
 		 */
 		public function __set($key, $value) {
 			switch ($key) {
+				case "mode": $this->mode = $value; break;
 				case "language": $this->language = $value; break;
 				case "description": $this->description = $value; break;
 				case "keywords": $this->keywords = $value; break;
@@ -173,12 +173,23 @@
 		 * OUTPUT: bool layout accepted
 		 * ERROR:  -
 		 */
-		public function set_layout($layout) {
-			if (file_exists("../views/includes/".$layout.".xslt") == false) {
-				return false;
-			}
+		public function set_layout($layout = null) {
+			if ($layout == null) {
+				$inherit_layout = array(LOGOUT_MODULE, "password");
+				if (substr($this->page->url, 0, 6) == "/admin") {
+					$this->layout = LAYOUT_CMS;
+				} else if (in_array($this->page->module, $inherit_layout)) {
+					if ($_SESSION["previous_layout"] == LAYOUT_CMS) {
+						$this->layout = LAYOUT_CMS;
+					}
+				}
+			} else {
+				if (file_exists("../views/includes/".$layout.".xslt") == false) {
+					return false;
+				}
 
-			$this->layout = $layout;
+				$this->layout = $layout;
+			}
 
 			return true;
 		}
@@ -291,7 +302,7 @@
 		 * OUTPUT: -
 		 * ERROR:  -
 		 */
-		public function generate($output, $view = null) {
+		public function generate($view = null) {
 			if ($this->disabled) {
 				return;
 			}
@@ -300,7 +311,7 @@
 				$output = "xml";
 			}
 
-			switch ($output) {
+			switch ($this->mode) {
 				case "xml":
 					header("Content-Type: text/xml");
 					print $this->document;
@@ -310,7 +321,7 @@
 					print $this->document;
 					break;
 				case null:
-					if (($html = parent::transform($view)) === false) {
+					if (($html = parent::transform($this->page->view)) === false) {
 						print "XSL Transformation error";
 						return;
 					}
