@@ -173,22 +173,6 @@
 				return;
 			}
 
-			/* Page aliases
-			 */
-			foreach (config_file("page_aliases") as $line) {
-				list($from, $to) = explode("->", $line);
-				
-				$from = trim($from);
-				$length = strlen($from);
-
-				if (substr($page."/", 0, $length + 1) === substr($from."/", 0, $length + 1)) {
-					$page = trim($to).substr($page, $length);
-					$this->url = "/".$page;
-					$this->page = $from;
-					break;
-				}
-			}
-
 			/* Public page
 			 */
 			if (($this->module = $this->page_on_disk($page, "public_pages")) !== null) {
