@@ -27,18 +27,22 @@
 
 			/* Preload often used settings
 			 */
-			if (($count = count($preload_settings)) > 0) {
-				$query = "select * from settings where %S in (".implode(", ", array_fill(1, $count, "%s")).")";
-				$settings = $db->execute($query, "key", $preload_settings);
+			if (($count = count($preload_settings)) == 0) {
+				return;
+			}
 
-				foreach ($settings as $setting) {
-					$value = $setting["value"];
-					switch ($setting["type"]) {
-						case "integer": $value = (int)$value; break;
-						case "boolean": $value = is_true($value); break;
-					}
-					$this->cache[$setting["key"]] = $value;
+			$query = "select * from settings where %S in (".implode(", ", array_fill(1, $count, "%s")).")";
+			if (($settings = $db->execute($query, "key", $preload_settings)) == false) {
+				return;
+			}
+
+			foreach ($settings as $setting) {
+				$value = $setting["value"];
+				switch ($setting["type"]) {
+					case "integer": $value = (int)$value; break;
+					case "boolean": $value = is_true($value); break;
 				}
+				$this->cache[$setting["key"]] = $value;
 			}
 		}
 
@@ -56,6 +60,10 @@
 			if (isset($this->cache[$key])) {
 				return $this->cache[$key];
 			}
+
+			if ($this->db->connected == false) {
+				return null;
+			}
 			
 			$query = "select * from settings where %S=%s";
 			if (($setting = $this->db->execute($query, "key", $key)) === false) {
