@@ -8,7 +8,8 @@
 		"Chrome/?" => "Chrome",
 		"Chrome ?",
 		"Safari",
-		"Opera",
+		"Opera ?",
+		"Opera/?" => "Opera",
 		"Konqueror",
 		"Googlebot" => "Google searchbot",
 		"Feedfetcher-Google" => "Google searchbot",
