@@ -6,11 +6,10 @@
 	 * http://www.banshee-php.org/
 	 */
 
-	define("XML_HEADER", "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>");
-
 	class XML {
-		protected $db = null;
-		protected $xml_data = "";
+		private $xml_header = "<?xml version=\"1.0\" encoding=\"utf-8\"?>";
+		private $db = null;
+		private $xml_data = "";
 		private $xslt_parameters = array();
 		private $open_tags = array();
 		private $cache_id = null;
@@ -37,7 +36,7 @@
 			switch ($key) {
 				case "depth": return count($this->open_tags);
 				case "data": return $this->xml_data;
-				case "document": return XML_HEADER."\n".$this->xml_data;
+				case "document": return $this->xml_header."\n".$this->xml_data;
 			}
 
 			return null;
