@@ -1,10 +1,6 @@
 <?php
-	class table_manager extends tablemanager {
-		protected $name = "Webserver";
+	class admin_webserver_model extends tablemanager_model {
 		protected $table = "webservers";
-		protected $pathinfo_offset = 2;
-		protected $back = "admin";
-		protected $icon = "webserver.png";
 		protected $elements = array(
 			"name" => array(
 				"label"    => "Name",
@@ -34,21 +30,15 @@
 				"overview" => true,
 				"required" => true));
 
-		public function delete_oke($item_id) {	
-			global $_output;
+		public function delete_item($item_id) {
+			$queries = array(
+				array("delete from actions where webserver_id=%d", $item_id),
+				array("delete from host_statistics where webserver_id=%d", $item_id),
+				array("delete from requests where webserver_id=%d", $item_id),
+				array("delete from server_statistics where webserver_id=%d", $item_id),
+				array("delete from webservers where id=%d", $item_id));
 
-			foreach (array("requests", "statistics") as $table) {
-				$query = "select count(*) as count from %S  where webserver_id=%d";
-				if (($result = $this->db->execute($query, $table, $item_id)) === false) {
-					return false;
-				}
-				if ($result[0]["count"] > 0) {
-					$_output->add_message("Webserver is in use.");
-					return false;
-				}
-			}
-
-			return true;
+			return $this->db->transaction($queries);
 		}
 	}
 ?>
