@@ -25,7 +25,7 @@
 		}
 
 		public function get_top_forbiddens($timestamp) {
-			$query = "select sum(result_forbidden) as forbidden, h.hostname ".
+			$query = "select sum(result_forbidden) as forbidden, h.id, h.hostname ".
 					 "from host_statistics s, hostnames h ".
 					 "where s.hostname_id=h.id and s.timestamp_begin>%s and result_forbidden>0 ".
 					 "group by hostname order by forbidden desc";
@@ -34,7 +34,7 @@
 		}
 
 		public function get_top_not_founds($timestamp) {
-			$query = "select h.id, sum(result_not_found) as not_found, h.hostname ".
+			$query = "select h.id, sum(result_not_found) as not_found, h.id, h.hostname ".
 					 "from host_statistics s, hostnames h ".
 					 "where s.hostname_id=h.id and s.timestamp_begin>%s and result_not_found>0 ".
 					 "group by hostname order by not_found desc";
@@ -43,7 +43,7 @@
 		}
 
 		public function get_top_internal_errors($timestamp) {
-			$query = "select sum(result_internal_error) as errors, h.hostname ".
+			$query = "select sum(result_internal_error) as errors, h.id, h.hostname ".
 					 "from host_statistics s, hostnames h ".
 					 "where s.hostname_id=h.id and s.timestamp_begin>%s and result_internal_error>0 ".
 					 "group by hostname order by errors desc";
