@@ -1,9 +1,9 @@
 <?php
 	class origins_model extends model {
-		public function get_origins($begin, $end, $filter_hostname, $filter_webserver) {
+		public function get_origins($filter_hostname, $filter_webserver) {
 			$query = "select count(*) as count, c.country ".
 					 "from requests r, ip2nationCountries c ".
-					 "where r.country_id=c.code and r.timestamp>%s and r.timestamp<%s";
+					 "where r.country_id=c.code";
 
 			$filter_args = array();
 			if ($filter_hostname != 0) {
@@ -17,7 +17,7 @@
 
 			$query .= " group by country order by count desc";
 
-			return $this->db->execute($query, $begin, $end, $filter_args);
+			return $this->db->execute($query, $filter_args);
 		}
 	}
 ?>
