@@ -78,16 +78,6 @@
 		 */
 		$_output->add_css($_page->module.".css");
 
-		/* Old browser notification
-		 */
-		if (preg_match("/MSIE [123456]/", $_SERVER["HTTP_USER_AGENT"]) > 0) {
-			if ($_SESSION["old_browser"] != 1) {
-				$_SESSION["old_browser"] = 1;
-				$_output->add_css("includes/old_browser.css");
-				$_output->add_tag("old_browser");
-			}
-		}
-
 		$_output->open_tag("content");
 	}
 
@@ -129,5 +119,5 @@
 
 	/* Output content
 	 */
-	$_output->generate($_GET["output"], $_page->view);
+	$_output->generate();
 ?>
